==> agentbox_python_sdk-0.1.4.tar.gz: agentbox_python_sdk-0.1.4/agentbox/api/client/api/sandboxes/get_sandboxes_metrics.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.error import Error
from ...models.running_sandbox_with_metrics import RunningSandboxWithMetrics
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    metadata: Union[Unset, str] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["metadata"] = metadata

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/sandboxes/metrics",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Error, list["RunningSandboxWithMetrics"]]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = RunningSandboxWithMetrics.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    if response.status_code == 400:
        response_400 = Error.from_dict(response.json())

        return response_400
    if response.status_code == 401:
        response_401 = Error.from_dict(response.json())

        return response_401
    if response.status_code == 500:
        response_500 = Error.from_dict(response.json())

        return response_500
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Error, list["RunningSandboxWithMetrics"]]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    metadata: Union[Unset, str] = UNSET,
) -> Response[Union[Error, list["RunningSandboxWithMetrics"]]]:
    """List all running sandboxes with metrics

    Args:
        metadata (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Error, list['RunningSandboxWithMetrics']]]
    """

    kwargs = _get_kwargs(
        metadata=metadata,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    metadata: Union[Unset, str] = UNSET,
) -> Optional[Union[Error, list["RunningSandboxWithMetrics"]]]:
    """List all running sandboxes with metrics

    Args:
        metadata (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Error, list['RunningSandboxWithMetrics']]
    """

    return sync_detailed(
        client=client,
        metadata=metadata,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    metadata: Union[Unset, str] = UNSET,
) -> Response[Union[Error, list["RunningSandboxWithMetrics"]]]:
    """List all running sandboxes with metrics

    Args:
        metadata (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Error, list['RunningSandboxWithMetrics']]]
    """

    kwargs = _get_kwargs(
        metadata=metadata,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    metadata: Union[Unset, str] = UNSET,
) -> Optional[Union[Error, list["RunningSandboxWithMetrics"]]]:
    """List all running sandboxes with metrics

    Args:
        metadata (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Error, list['RunningSandboxWithMetrics']]
    """

    return (
        await asyncio_detailed(
            client=client,
            metadata=metadata,
        )
    ).parsed

==> agentbox_python_sdk-1.0.7.tar.gz: agentbox_python_sdk-1.0.7/agentbox/api/client/api/sandboxes/get_sandboxes_metrics.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.error import Error
from ...models.running_sandbox_with_metrics import RunningSandboxWithMetrics
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    metadata: Union[Unset, str] = UNSET,
    sandbox_ids: Union[Unset, list[str]] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["metadata"] = metadata

    json_sandbox_ids: Union[Unset, list[str]] = UNSET
    if not isinstance(sandbox_ids, Unset):
        json_sandbox_ids = sandbox_ids

    params["sandbox_ids"] = json_sandbox_ids

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/sandboxes/metrics",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Error, list["RunningSandboxWithMetrics"]]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = RunningSandboxWithMetrics.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200

    if response.status_code == 400:
        response_400 = Error.from_dict(response.json())

        return response_400

    if response.status_code == 401:
        response_401 = Error.from_dict(response.json())

        return response_401

    if response.status_code == 500:
        response_500 = Error.from_dict(response.json())

        return response_500

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Error, list["RunningSandboxWithMetrics"]]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    metadata: Union[Unset, str] = UNSET,
    sandbox_ids: Union[Unset, list[str]] = UNSET,
) -> Response[Union[Error, list["RunningSandboxWithMetrics"]]]:
    """List all running sandboxes with metrics

    Args:
        metadata (Union[Unset, str]):
        sandbox_ids (Union[Unset, list[str]]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Error, list['RunningSandboxWithMetrics']]]
    """

    kwargs = _get_kwargs(
        metadata=metadata,
        sandbox_ids=sandbox_ids,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    metadata: Union[Unset, str] = UNSET,
    sandbox_ids: Union[Unset, list[str]] = UNSET,
) -> Optional[Union[Error, list["RunningSandboxWithMetrics"]]]:
    """List all running sandboxes with metrics

    Args:
        metadata (Union[Unset, str]):
        sandbox_ids (Union[Unset, list[str]]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Error, list['RunningSandboxWithMetrics']]
    """

    return sync_detailed(
        client=client,
        metadata=metadata,
        sandbox_ids=sandbox_ids,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    metadata: Union[Unset, str] = UNSET,
    sandbox_ids: Union[Unset, list[str]] = UNSET,
) -> Response[Union[Error, list["RunningSandboxWithMetrics"]]]:
    """List all running sandboxes with metrics

    Args:
        metadata (Union[Unset, str]):
        sandbox_ids (Union[Unset, list[str]]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Error, list['RunningSandboxWithMetrics']]]
    """

    kwargs = _get_kwargs(
        metadata=metadata,
        sandbox_ids=sandbox_ids,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    metadata: Union[Unset, str] = UNSET,
    sandbox_ids: Union[Unset, list[str]] = UNSET,
) -> Optional[Union[Error, list["RunningSandboxWithMetrics"]]]:
    """List all running sandboxes with metrics

    Args:
        metadata (Union[Unset, str]):
        sandbox_ids (Union[Unset, list[str]]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Error, list['RunningSandboxWithMetrics']]
    """

    return (
        await asyncio_detailed(
            client=client,
            metadata=metadata,
            sandbox_ids=sandbox_ids,
        )
    ).parsed
